@@ -145,7 +145,7 @@ class ScraperWrapper(threading.Thread):
         if True:
             response = json.loads(body)
             if self.DEBUG:
-                print "Processing Message:\n\t{0}".format(response)
+                print "Processing Message:\n\t{0}".format(response['command'])
             if response['command'] == 'url_dispatch':
                 if response['destinationid'] == self.uid:
                     #print "URL Dispatch Command Seen."
